==> hoteldruid-mod-ru_3.0.4-1.tar.gz: ru/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Вставьте правила размещения для броней года"; break;
case "Regola di assegnazione":  		$messaggio = "Правило размещения"; break;
case "nel periodo dal":  			$messaggio = "в период от"; break;
case "al":  					$messaggio = "к"; break;
case "motivazione":  				$messaggio = "причина"; break;
case "Inserisci la regola":  			$messaggio = "Вставить правило"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Вставить или изменить правило"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Удалить все правила этого вида"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Когда выбирается тариф"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "если никакой другой способ размещения не добавлен"; break;
case "Vedi le regole già inserite":  		$messaggio = "Посмотреть уже вставленные правила"; break;
case "Torna al menù principale":  		$messaggio = "Назад к главному меню"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Не все необходимые данные были вставлены"; break;
case "Le date sono sbagliate":  		$messaggio = "Даты неправильны"; break;
case "opzionale":  				$messaggio = "необязательный"; break;
case "La regola è stata inserita":  		$messaggio = "Правило было вставлено"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Вы уверены, что хотите удалить все правила типа 1"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Le regole sono state cancellate":  	$messaggio = "Правила были удалены"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Вы должны выбрать тариф"; break;
case " non esiste":  				$messaggio = " не существует"; break;
case "La regola di assegnazione":		$messaggio = "Правило назначения"; break;
case "è stata inserita":			$messaggio = "было вставлено"; break;
case "è stata modificata":			$messaggio = "было изменено"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Motivazione non valida":  		$messaggio = "Недействительная причина"; break;
case "Quando l'utente amministratore":  	$messaggio = "Когда администратор"; break;
case "sceglie la tariffa":  			$messaggio = "выбирает тариф"; break;
case "fai risultare come se l'utente":  	$messaggio = "показать как будто бы это был пользователь"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "вставил бронь и возможного клиента"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Вам придется выбрать пользователя, который будет связан"; break;
case "L'utente ":  				$messaggio = "Пользователь "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "автоматически назначить как номер группы людей"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "если никакой другой номер не вставлен"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Вам придется выбрать номер группы людей, которые будут связаны"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned user, delete the rule before inserting a new one"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ru_3.0.8-1.tar.gz: ru/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Вставьте правила размещения для броней года"; break;
case "Regola di assegnazione":  		$messaggio = "Правило размещения"; break;
case "nel periodo dal":  			$messaggio = "в период от"; break;
case "al":  					$messaggio = "к"; break;
case "motivazione":  				$messaggio = "причина"; break;
case "Inserisci la regola":  			$messaggio = "Вставить правило"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Вставить или изменить правило"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Удалить все правила этого вида"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Когда выбирается тариф"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "если никакой другой способ размещения не добавлен"; break;
case "Vedi le regole già inserite":  		$messaggio = "Посмотреть уже вставленные правила"; break;
case "Torna al menù principale":  		$messaggio = "Назад к главному меню"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Не все необходимые данные были вставлены"; break;
case "Le date sono sbagliate":  		$messaggio = "Даты неправильны"; break;
case "opzionale":  				$messaggio = "необязательный"; break;
case "La regola è stata inserita":  		$messaggio = "Правило было вставлено"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Вы уверены, что хотите удалить все правила типа 1"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Le regole sono state cancellate":  	$messaggio = "Правила были удалены"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Вы должны выбрать тариф"; break;
case " non esiste":  				$messaggio = " не существует"; break;
case "La regola di assegnazione":		$messaggio = "Правило назначения"; break;
case "è stata inserita":			$messaggio = "было вставлено"; break;
case "è stata modificata":			$messaggio = "было изменено"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Motivazione non valida":  		$messaggio = "Недействительная причина"; break;
case "Quando l'utente amministratore":  	$messaggio = "Когда администратор"; break;
case "sceglie la tariffa":  			$messaggio = "выбирает тариф"; break;
case "fai risultare come se l'utente":  	$messaggio = "показать как будто бы это был пользователь"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "вставил бронь и возможного клиента"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Вам придется выбрать пользователя, который будет связан"; break;
case "L'utente ":  				$messaggio = "Пользователь "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "автоматически назначить как номер группы людей"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "если никакой другой номер не вставлен"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Вам придется выбрать номер группы людей, которые будут связаны"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned user, delete the rule before inserting a new one"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "do not allow inserting reservations with less than"; break;
case "Il numero di persone minimo":  		$messaggio = "The minimum number of people"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "is bigger then the default number of people"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
